==> clusteval-2.2.2.tar.gz: clusteval-2.2.2/setup.py <==
import setuptools
import re

# versioning ------------
VERSIONFILE="clusteval/__init__.py"
getversion = re.search( r"^__version__ = ['\"]([^'\"]*)['\"]", open(VERSIONFILE, "rt").read(), re.M)
if getversion:
    new_version = getversion.group(1)
else:
    raise RuntimeError("Unable to find version string in %s." % (VERSIONFILE,))

# Setup ------------
with open("README.md", "r", encoding='utf8') as fh:
    long_description = fh.read()
setuptools.setup(
     install_requires=['scatterd>=1.3.5',
                       'pypickle',
                       'matplotlib',
                       'numpy',
                       'pandas',
                       'tqdm',
                       'seaborn',
                       'scikit-learn',
                       'colourmap>=1.1.14'],
     python_requires='>=3',
     name='clusteval',
     version=new_version,
     author="Erdogan Taskesen",
     author_email="erdogant@gmail.com",
     description="clusteval is a python package for unsupervised cluster validation.",
     long_description=long_description,
     long_description_content_type="text/markdown",
     url="https://erdogant.github.io/clusteval",
     download_url = 'https://github.com/erdogant/clusteval/archive/'+new_version+'.tar.gz',
     packages=setuptools.find_packages(), # Searches throughout all dirs for files to include
     include_package_data=True, # Must be true to include files depicted in MANIFEST.in
     license_files=["LICENSE"],
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],
 )

==> clusteval-2.2.3.tar.gz: clusteval-2.2.3/setup.py <==
import setuptools
import re

# versioning ------------
VERSIONFILE="clusteval/__init__.py"
getversion = re.search( r"^__version__ = ['\"]([^'\"]*)['\"]", open(VERSIONFILE, "rt").read(), re.M)
if getversion:
    new_version = getversion.group(1)
else:
    raise RuntimeError("Unable to find version string in %s." % (VERSIONFILE,))

# Setup ------------
with open("README.md", "r", encoding='utf8') as fh:
    long_description = fh.read()
setuptools.setup(
     install_requires=['scatterd>=1.3.5',
                       'pypickle',
                       'matplotlib',
                       'numpy',
                       'pandas',
                       'tqdm',
                       'seaborn',
                       'scikit-learn',
                       'colourmap>=1.1.14',
                       'datazets>=1.1.0',
                       ],
     python_requires='>=3',
     name='clusteval',
     version=new_version,
     author="Erdogan Taskesen",
     author_email="erdogant@gmail.com",
     description="clusteval is a python package for unsupervised cluster validation.",
     long_description=long_description,
     long_description_content_type="text/markdown",
     url="https://erdogant.github.io/clusteval",
     download_url = 'https://github.com/erdogant/clusteval/archive/'+new_version+'.tar.gz',
     packages=setuptools.find_packages(), # Searches throughout all dirs for files to include
     include_package_data=True, # Must be true to include files depicted in MANIFEST.in
     license_files=["LICENSE"],
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],
 )
